pub struct ElementLayout { /* private fields */ }Expand description
Information about the size of individual elements (vertices or indices) within a slab.
Slab objects are allocated in units of slots. Usually, each element takes
up one slot, and so elements and slots are equivalent. Occasionally,
however, a slot may consist of 2 or even 4 elements. This occurs when the
size of an element isn’t divisible by COPY_BUFFER_ALIGNMENT. When we
resize buffers, we perform GPU-to-GPU copies to shuffle the existing
elements into their new positions, and such copies must be on
COPY_BUFFER_ALIGNMENT boundaries. Slots solve this problem by
guaranteeing that the size of an allocation quantum is divisible by both the
size of an element and COPY_BUFFER_ALIGNMENT, so we can relocate it
freely.