pub struct MeshAllocator { /* private fields */ }Expand description
Manages the assignment of mesh data to GPU buffers.
The Bevy renderer tries to pack vertex and index data for multiple meshes together so that multiple meshes can be drawn back-to-back without any rebinding. This resource manages these buffers.
The MeshAllocatorSettings allows you to tune the behavior of the
allocator for better performance with your use case. Most applications won’t
need to change the settings from their default values.
Implementations
Sourceimpl MeshAllocator
impl MeshAllocator
Sourcepub fn mesh_vertex_slice(
&self,
mesh_id: &AssetId<Mesh>,
) -> Option<MeshBufferSlice<'_>>
pub fn mesh_vertex_slice( &self, mesh_id: &AssetId<Mesh>, ) -> Option<MeshBufferSlice<'_>>
Returns the buffer and range within that buffer of the vertex data for the mesh with the given ID.
If the mesh wasn’t allocated, returns None.
Sourcepub fn mesh_index_slice(
&self,
mesh_id: &AssetId<Mesh>,
) -> Option<MeshBufferSlice<'_>>
pub fn mesh_index_slice( &self, mesh_id: &AssetId<Mesh>, ) -> Option<MeshBufferSlice<'_>>
Returns the buffer and range within that buffer of the index data for the mesh with the given ID.
If the mesh has no index data or wasn’t allocated, returns None.
Sourcepub fn mesh_slabs(&self, mesh_id: &AssetId<Mesh>) -> Option<MeshSlabs>
pub fn mesh_slabs(&self, mesh_id: &AssetId<Mesh>) -> Option<MeshSlabs>
Returns the IDs of the vertex buffer and index buffer respectively for the mesh with the given ID.
If the mesh wasn’t allocated, or has no index data in the case of the index buffer, the corresponding element in the returned tuple will be None.
Sourcepub fn index_allocation_count(&self) -> usize
pub fn index_allocation_count(&self) -> usize
Returns the number of index allocations that this mesh allocator manages.
Methods from Deref<Target = SlabAllocator<MeshSlabItem>>
Sourcepub fn stage_allocation(&mut self) -> AllocationStage<'_, I>
pub fn stage_allocation(&mut self) -> AllocationStage<'_, I>
Creates an AllocationStage, enabling batched allocation of objects
in this slab.
Allocation of objects in the slab requires calling this function,
calling AllocationStage::allocate on the resulting
AllocationStage, and finally calling AllocationStage::commit.
Grouping allocations into a batch, preferably at most one per frame, is
the most efficient way to perform many allocations at once.
Sourcepub fn stage_deallocation(&mut self) -> DeallocationStage<'_, I>
pub fn stage_deallocation(&mut self) -> DeallocationStage<'_, I>
Creates a DeallocationStage, enabling batched deallocation.
Deallocation of objects in the slab requires calling this function,
calling DeallocationStage::free on the resulting
DeallocationStage, and finally calling
DeallocationStage::commit. Grouping deallocations into a batch,
preferably at most one per frame, is the most efficient way to perform
many deallocations at once.
Sourcepub fn buffer_for_slab(&self, slab_id: SlabId<I>) -> Option<&Buffer>
pub fn buffer_for_slab(&self, slab_id: SlabId<I>) -> Option<&Buffer>
Returns the GPU buffer corresponding to the slab with the given ID if that slab has been uploaded to the GPU.
Sourcepub fn slab_allocation_slice(
&self,
key: &I::Key,
slab_id: SlabId<I>,
) -> Option<SlabAllocationBufferSlice<'_, I>>
pub fn slab_allocation_slice( &self, key: &I::Key, slab_id: SlabId<I>, ) -> Option<SlabAllocationBufferSlice<'_, I>>
Given a slab and the key of data located with it, returns the buffer and range of that data within the slab.
Sourcepub fn slab_count(&self) -> usize
pub fn slab_count(&self) -> usize
Get the number of allocated slabs
Sourcepub fn slabs_size(&self) -> u64
pub fn slabs_size(&self) -> u64
Get the total size of all allocated slabs
Sourcepub fn copy_element_data(
&mut self,
key: &I::Key,
len: usize,
fill_data: impl Fn(WriteOnly<'_, [u8]>),
render_device: &RenderDevice,
render_queue: &RenderQueue,
)
pub fn copy_element_data( &mut self, key: &I::Key, len: usize, fill_data: impl Fn(WriteOnly<'_, [u8]>), render_device: &RenderDevice, render_queue: &RenderQueue, )
Copies data into an allocated slab.
len specifies the size of the data to be copied in bytes. The given
fill_data callback is expected to write the data into the given slice;
this callback approach avoids a copy.